import sys, pygame  # 导入需要的模块
from pygame.locals import *  # 导入所有常量
from random import randrange  # 导入随机范围的方法


class Enemy(pygame.sprite.Sprite):  # 通过图片创建游戏对象类
    def __init__(self):
        self.image = enemy_image
        pygame.sprite.Sprite.__init__(self)  # 重载超类的构造方法
        self.rect = self.image.get_rect()  # 从图片创建游戏对象的rect特性
        self.reset()  # 游戏对象重置位置

    def reset(self):  # 定义游戏对象重置位置的方法
        self.rect.top = -self.rect.height  # 设置游戏对象y轴初始随机位置
        self.rect.centerx = randrange(screen_size[0])  # 设置游戏对象x轴的随机位置

    def update(self):  # 重写超类中更新游戏对象位置的方法
        self.rect.top += 1  # 每次位置向下移动1像素
        if self.rect.top > screen_size[1]:  # 如果超出屏幕下边界
            self.reset()  # 重置位置


# 初始化
pygame.init()
screen_size = 360, 640  # 设置游戏屏幕尺寸
pygame.display.set_mode(screen_size, FULLSCREEN)  # 设置显示模式（FULLSCREEN：全屏）
pygame.mouse.set_visible(0)  # 隐藏鼠标指针

# 载入游戏对象的图像
enemy_image = pygame.image.load('enemy.png').convert_alpha()  # 载入图片

# 创建游戏对象集并添加游戏对象
sprites = pygame.sprite.RenderUpdates()  # 创建游戏对象集
sprites.add(Enemy())  # 添加游戏对象

# 设置屏幕外观
bgcolor = (255, 255, 255)  # 游戏屏幕背景颜色
screen = pygame.display.get_surface()  # 创建屏幕外观
screen.fill(bgcolor)  # 屏幕填充背景颜色
pygame.display.flip()  # 弹出屏幕


# 清除游戏对象
def clear_callback(surf, rect):  # 定义清除游戏对象的方法
    surf.fill(bgcolor, rect)  # 屏幕外观中的游戏对象区域填充背景颜色


# 监控退出事件
while True:
    for event in pygame.event.get():  # 获取事件
        if event.type == QUIT:  # 如果事件类型是退出
            sys.exit()  # 退出程序
        if event.type == KEYDOWN and event.key == K_ESCAPE:  # 如果事件类型为按键并且按键为ESC
            sys.exit()  # 退出程序
    # 实现游戏对象的不停移动
    pygame.time.Clock().tick(100)  # 设置每秒帧数
    sprites.clear(screen, clear_callback)  # 清除游戏对象经过的区域
    sprites.update()  # 更新所有游戏对象
    updates = sprites.draw(screen)  # 屏幕中绘制所有游戏对象
    pygame.display.update(updates)  # 更新所有游戏对象的显示
